==> webkit2gtk_2.28.1.orig.tar.xz: webkitgtk-2.28.1/Source/WebKit/WebProcess/Geolocation/GeolocationPermissionRequestManager.h <==
/*
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/HashMap.h>
#include <wtf/RefPtr.h>

namespace WebCore {
class Geolocation;
}

namespace WebKit {

class WebPage;

class GeolocationPermissionRequestManager {
    WTF_MAKE_FAST_ALLOCATED;
public:
    explicit GeolocationPermissionRequestManager(WebPage&);

    void startRequestForGeolocation(WebCore::Geolocation&);
    void cancelRequestForGeolocation(WebCore::Geolocation&);
    void revokeAuthorizationToken(const String&);

    void didReceiveGeolocationPermissionDecision(uint64_t geolocationID, const String& authorizationToken);

private:
    typedef HashMap<uint64_t, WebCore::Geolocation*> IDToGeolocationMap;
    typedef HashMap<WebCore::Geolocation*, uint64_t> GeolocationToIDMap;
    IDToGeolocationMap m_idToGeolocationMap;
    GeolocationToIDMap m_geolocationToIDMap;

    WebPage& m_page;
};

} // namespace WebKit

==> webkit2gtk_2.36.0.orig.tar.xz: webkitgtk-2.36.0/Source/WebKit/WebProcess/Geolocation/GeolocationPermissionRequestManager.h <==
/*
 * Copyright (C) 2011-2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "GeolocationIdentifier.h"
#include <wtf/HashMap.h>
#include <wtf/RefPtr.h>

namespace WebCore {
class Geolocation;
}

namespace WebKit {

class WebPage;

class GeolocationPermissionRequestManager {
    WTF_MAKE_FAST_ALLOCATED;
public:
    explicit GeolocationPermissionRequestManager(WebPage&);

    void startRequestForGeolocation(WebCore::Geolocation&);
    void cancelRequestForGeolocation(WebCore::Geolocation&);
    void revokeAuthorizationToken(const String&);

    void didReceiveGeolocationPermissionDecision(GeolocationIdentifier, const String& authorizationToken);

private:
    typedef HashMap<GeolocationIdentifier, WebCore::Geolocation*> IDToGeolocationMap;
    typedef HashMap<WebCore::Geolocation*, GeolocationIdentifier> GeolocationToIDMap;
    IDToGeolocationMap m_idToGeolocationMap;
    GeolocationToIDMap m_geolocationToIDMap;

    WebPage& m_page;
};

} // namespace WebKit
